@@ -93,7 +93,7 @@ class CPUInfoBase(object):
 
     def __get_nbits(self):
         abits = platform.architecture()[0]
-        nbits = re.compile('(\d+)bit').search(abits).group(1)
+        nbits = re.compile(r'(\d+)bit').search(abits).group(1)
         return nbits
 
     def _is_32bit(self):
@@ -117,7 +117,7 @@ class LinuxCPUInfo(CPUInfoBase):
             fo = open('/proc/cpuinfo')
         except EnvironmentError:
             e = get_exception()
-            warnings.warn(str(e), UserWarning)
+            warnings.warn(str(e), UserWarning, stacklevel=2)
         else:
             for line in fo:
                 name_value = [s.strip() for s in line.split(':', 1)]
@@ -495,8 +495,8 @@ class Win32CPUInfo(CPUInfoBase):
             else:
                 import _winreg as winreg
 
-            prgx = re.compile(r"family\s+(?P<FML>\d+)\s+model\s+(?P<MDL>\d+)"\
-                              "\s+stepping\s+(?P<STP>\d+)", re.IGNORECASE)
+            prgx = re.compile(r"family\s+(?P<FML>\d+)\s+model\s+(?P<MDL>\d+)"
+                              r"\s+stepping\s+(?P<STP>\d+)", re.IGNORECASE)
             chnd=winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, self.pkey)
             pnum=0
             while True:
@@ -681,13 +681,13 @@ cpu = cpuinfo()
 #    cpu.is_Intel()
 #    cpu.is_Alpha()
 #
-#    print 'CPU information:',
+#    print('CPU information:'),
 #    for name in dir(cpuinfo):
 #        if name[0]=='_' and name[1]!='_':
 #            r = getattr(cpu,name[1:])()
 #            if r:
 #                if r!=1:
-#                    print '%s=%s' %(name[1:],r),
+#                    print('%s=%s' %(name[1:],r))
 #                else:
-#                    print name[1:],
-#    print
+#                    print(name[1:]),
+#    print()
